<?php
/**
 * CommonPlugin for phplist.
 *
 * This file is a part of CommonPlugin.
 *
 * @category  phplist
 *
 * @author    Duncan Cameron
 * @copyright 2011-2018 Duncan Cameron
 * @license   http://www.gnu.org/licenses/gpl.html GNU General Public License, Version 3
 */

/**
 * This file contains the Japanese translation of the English text.
 */
return [
//  CommonPlugin.php
    ['phpinfo', 'phpinfoを表示'],
    ['config.php', 'config.phpを表示'],
    ['php session', 'phpセッションを表示'],
//  Pager.php
    ['Showing %d to %d of %d', '%d 件目から %d 件目を表示 (%d 件中)'],
    ['no_results', '表示結果はありません。'],
//  Toolbar.php
    ['help', 'ヘルプ'],
//  Widget.php
    ['Select attributes', '属性を選択する'],
//  General
    ['top', 'トップ'],
//  widget_attributeform.tpl.php
    ['Search for', '検索'],
    ['All', 'すべて'],
    ['confirmed only', '承認済のみ'],
    ['unconfirmed only', '未承認のみ'],
    ['blacklisted only', 'ブラックリストのみ'],
    ['not blacklisted only', '非ブラックリストのみ'],
//  ExportCSVAsync.php
    ['Exporting, this may take a while', 'エクスポート中：お待ちください。'],
    ['Generating the export data', 'エクスポートデータを生成中'],
    ['Exported %d of %d %d%%', 'エクスポート %d 件 %d 件中 %d%%'],
];
